/**
 * Perform the specified action for each element in an array.
 * When `callbackFn` returns a `number`, moves to the element at that index next.
 *
 * @template {any} Value
 * @template {ArrayLike<Value>} Values
 * @param {Values} values Values to iterate over
 * @param {(value: Value, index: number, array: Values) => number | void} callbackFn A function that accepts up to three arguments
 * @param {any} [thisArg] thisArg An object to which the this keyword can refer in `callbackFn`. If `thisArg` is omitted, `undefined` is used as the `this` value.
 * @returns {void}
 */
export function arrayIterate<
  Value extends unknown,
  Values extends ArrayLike<Value>
>(
  values: Values,
  callbackFn: (value: Value, index: number, array: Values) => number | void,
  thisArg?: any
): void
